@@ -25,9 +25,6 @@ def login(driver, email=None, password=None):
 
   password_elem = driver.find_element_by_id("password")
   password_elem.send_keys(password)
-
-  Scraper.__find_first_available_element__(
-    driver.find_elements_by_xpath("//button[@aria-label='Sign in']")
-  ).click()
+  password_elem.submit()
 
   element = WebDriverWait(driver, 10).until(EC.presence_of_element_located((By.ID, "profile-nav-item")))
